﻿using BlazorServerChat.Common;
using BlazorServerChat.Models;
using System.Text.Encodings.Web;
using System.Text.Json;
using System.Text.Unicode;


//===========================================================
// Подробное описание работы классов и методов исходника на:
// https://www.interestprograms.ru
// Исходные коды программ и игр
//===========================================================

namespace BlazorServerChat.Data
{
    public class ReadUpdateDB
    {
        public async Task<ChatMessages> ReadFromDBAsync()
        {
            return await Task.Run(() =>
            {
                try
                {
                    using FileStream fs = File.OpenRead(Constants.PathDB);
                    ChatMessages? messages = JsonSerializer.Deserialize<ChatMessages>(fs);

                    // Избегаем объектов null.
                    return messages ?? new();
                }
                catch
                {
                    File.WriteAllText(Constants.PathDB, "{}");
                    return new ChatMessages();
                }

            });
        }

        public async Task WriteToDBAsync(ChatMessages messages)
        {
            await Task.Run(() =>
            {
                var serializerOptions = new JsonSerializerOptions
                {
                    // Формирует вид, удобный для чтения и печати.
                    WriteIndented = true,

                    // Настройка кодировки символов для кириллицы.
                    // По умолчанию сериализатор выполняет escape - последовательность символов,
                    // отличных от ASCII.То есть он заменяет их \uxxxx,
                    // где xxxx является кодом Юникода символа.
                    Encoder = JavaScriptEncoder.Create(UnicodeRanges.All)
                };


                using FileStream fs = File.OpenWrite(Constants.PathDB);
                JsonSerializer.Serialize(fs, messages, typeof(ChatMessages), serializerOptions);

            });

        }

        public void DeleteMessages()
        {
            File.WriteAllText(Constants.PathDB, "{}");
        }
    }
}
